/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.camel.test;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;

import org.apache.felix.ipojo.junit4osgi.OSGiTestCase;

/**
 * test the trace example bundle.
 * 
 * @author Malek CHAHINE
 */
public class CamelTraceTest extends OSGiTestCase {

    /**
     * Camel test Directory.
     */
    private static final File CAMEL_TEST_DIR = new File("target/camel-test");

    /**
     * Time out.
     */
    private static final int START_TIMEOUT = 10;

    /**
     * Test the trace example
     * 
     * @throws InterruptedException InterruptedException
     * @throws IOException InterruptedException
     */
    public void testTrace() throws InterruptedException, IOException {
        try {
            File source = new File(CAMEL_TEST_DIR, "source");
            File target = new File(CAMEL_TEST_DIR, "target");
            source.mkdirs();
            target.mkdirs();

            // Send five times a message on a given endpoint. The registry
            // component is a default one provided by the camel service.
            final int iterationNumber = 1;

            for (int i = 0; i < iterationNumber; i++) {
                File file = new File(source, "file" + i + ".txt");
                file.createNewFile();

                PrintWriter pw;

                pw = new PrintWriter(new BufferedWriter(new FileWriter(file)));

                pw.println("test File");

                pw.close();
            }

            File result = new File(target, "report.txt");

            // active wait
            final long stopTime = System.currentTimeMillis() + CamelTraceTest.START_TIMEOUT * 1000;
            while (!result.exists() && System.currentTimeMillis() < stopTime) {
                Thread.sleep(1000);
            }

            assertTrue("Assert that the file " + result.getAbsolutePath() + " is correctly created", result.exists());
        } finally {
            this.delete(CAMEL_TEST_DIR);
        }
    }

    /**
     * Delete directory.
     * 
     * @param dir : the directory name
     */
    private void delete(final File dir) {
        File[] files = dir.listFiles();
        if (files != null) {
            for (File file : files) {
                if (file.isDirectory()) {
                    this.delete(file);
                } else {
                    file.delete();
                }
            }
        }
    }
}
